@@ -17,7 +17,7 @@ def build_dataloader(dataset: Dataset,
                      batch_size: int,
                      num_workers: int,
                      shuffle: bool = True,
-                     persistent_workers: bool = True,
+                     persistent_workers: bool = False,
                      phase: str = "train",
                      distributed=True,
                      **kwargs) -> DataLoader:
@@ -28,7 +28,7 @@ def build_dataloader(dataset: Dataset,
     :param shuffle:
     :param persistent_workers: 该参数仅支持torch>=1.6
            False: 数据加载器运行完一个Epoch后会关闭worker进程,在分布式训练，会出现每个epoch初始化多进程的问题
-           True: 会保持worker进程实例激活状态
+           True: 会保持worker进程实例激活状态,容易出现“DataLoader worker (pid(s) 953) exited unexpectedly”的错误
     :param phase: "train", "test", "val"
     :param distributed: True: use DDP; False: use DP (是否使用分布式训练)
     :param kwargs:
@@ -45,6 +45,7 @@ def build_dataloader(dataset: Dataset,
         shuffle = False  # sampler option is mutually exclusive with shuffle
     else:
         # Fix a Bug: RuntimeError: can't start new thread
+        # Fix a Bug: DataLoader worker (pid(s) 953) exited unexpectedly
         persistent_workers = False
     try:
         # Fix a Bug: torch<=1.6 have no argument 'persistent_workers'
